@@ -70,17 +70,12 @@ class ISCSIConnectorTestCase(test_connector.ConnectorTestCase):
                     ('tcp:', 'session3', 'ip3:port3', '1', 'tgt3')]
         self.assertListEqual(expected, res)
 
-    @mock.patch.object(iscsi.ISCSIConnector, '_run_iscsi_session')
-    def test_get_iscsi_sessions_full_stderr(self, sessions_mock):
-        iscsiadm_result = ('tcp: [session1] ip1:port1,1 tgt1 (non-flash)\n'
-                           'tcp: [session2] ip2:port2,-1 tgt2 (non-flash)\n'
-                           'tcp: [session3] ip3:port3,1 tgt3\n')
-        sessions_mock.return_value = (iscsiadm_result, 'error')
+    @mock.patch.object(iscsi.ISCSIConnector, '_run_iscsi_session',
+                       return_value=(None, 'error'))
+    def test_get_iscsi_sessions_full_error(self, sessions_mock):
         res = self.connector._get_iscsi_sessions_full()
-        expected = [('tcp:', 'session1', 'ip1:port1', '1', 'tgt1'),
-                    ('tcp:', 'session2', 'ip2:port2', '-1', 'tgt2'),
-                    ('tcp:', 'session3', 'ip3:port3', '1', 'tgt3')]
-        self.assertListEqual(expected, res)
+        self.assertEqual([], res)
+        sessions_mock.assert_called()
 
     @mock.patch.object(iscsi.ISCSIConnector, '_get_iscsi_sessions_full')
     def test_get_iscsi_sessions(self, sessions_mock):
@@ -543,8 +538,7 @@ class ISCSIConnectorTestCase(test_connector.ConnectorTestCase):
         cleanup_mock.assert_called_once_with(
             mock.sentinel.con_props,
             force=mock.sentinel.Force,
-            ignore_errors=mock.sentinel.ignore_errors,
-            device_info=mock.sentinel.dev_info)
+            ignore_errors=mock.sentinel.ignore_errors)
 
     @ddt.data(True, False)
     @mock.patch.object(iscsi.ISCSIConnector, '_get_transport')
@@ -655,21 +649,13 @@ class ISCSIConnectorTestCase(test_connector.ConnectorTestCase):
             ['-m', 'discoverydb', '-o', 'show', '-P', 1])
         transport_mock.assert_called_once_with()
 
-    @ddt.data(('/dev/sda', False),
-              ('/dev/disk/by-id/scsi-WWID', False),
-              ('/dev/dm-11', True),
-              ('/dev/disk/by-id/dm-uuid-mpath-MPATH', True))
-    @ddt.unpack
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'get_dev_path')
     @mock.patch.object(iscsi.ISCSIConnector, '_disconnect_connection')
     @mock.patch.object(iscsi.ISCSIConnector, '_get_connection_devices')
     @mock.patch.object(linuxscsi.LinuxSCSI, 'flush_multipath_device')
     @mock.patch.object(linuxscsi.LinuxSCSI, 'remove_connection',
                        return_value=None)
-    def test_cleanup_connection(self, path_used, was_multipath, remove_mock,
-                                flush_mock, con_devs_mock, discon_mock,
-                                get_dev_path_mock):
-        get_dev_path_mock.return_value = path_used
+    def test_cleanup_connection(self, remove_mock, flush_mock, con_devs_mock,
+                                discon_mock):
         # Return an ordered dicts instead of normal dict for discon_mock.assert
         con_devs_mock.return_value = collections.OrderedDict((
             (('ip1:port1', 'tgt1'), ({'sda'}, set())),
@@ -680,16 +666,12 @@ class ISCSIConnectorTestCase(test_connector.ConnectorTestCase):
                                'use_multipath') as use_mp_mock:
             self.connector._cleanup_connection(
                 self.CON_PROPS, ips_iqns_luns=mock.sentinel.ips_iqns_luns,
-                force=False, ignore_errors=False,
-                device_info=mock.sentinel.device_info)
+                force=False, ignore_errors=False)
 
-        get_dev_path_mock.called_once_with(self.CON_PROPS,
-                                           mock.sentinel.device_info)
         con_devs_mock.assert_called_once_with(self.CON_PROPS,
                                               mock.sentinel.ips_iqns_luns)
         remove_mock.assert_called_once_with({'sda', 'sdb'}, use_mp_mock,
-                                            False, mock.ANY,
-                                            path_used, was_multipath)
+                                            False, mock.ANY)
         discon_mock.assert_called_once_with(
             self.CON_PROPS,
             [('ip1:port1', 'tgt1'), ('ip3:port3', 'tgt3')],
@@ -725,8 +707,7 @@ class ISCSIConnectorTestCase(test_connector.ConnectorTestCase):
         con_devs_mock.assert_called_once_with(self.CON_PROPS,
                                               mock.sentinel.ips_iqns_luns)
         remove_mock.assert_called_once_with({'sda', 'sdb'}, use_mp_mock,
-                                            mock.sentinel.force, mock.ANY,
-                                            '', False)
+                                            mock.sentinel.force, mock.ANY)
         discon_mock.assert_called_once_with(
             self.CON_PROPS,
             [('ip1:port1', 'tgt1'), ('ip3:port3', 'tgt3')],
@@ -1008,37 +989,6 @@ Setting up iSCSI targets: unused
         self.assertListEqual(expected_cmds, actual_cmds)
         self.assertEqual(2, get_sessions_mock.call_count)
 
-    @mock.patch.object(iscsi.ISCSIConnector, '_get_iscsi_sessions_full')
-    def test_connect_to_iscsi_portal_ip_case_insensitive(self,
-                                                         get_sessions_mock):
-        """Connect creating node and session."""
-        session = 'session2'
-        get_sessions_mock.side_effect = [
-            [('tcp:', 'session1', 'iP1:port1', '1', 'tgt')],
-            [('tcp:', 'session1', 'Ip1:port1', '1', 'tgt'),
-             ('tcp:', session, 'IP1:port1', '-1', 'tgt1')]
-        ]
-        with mock.patch.object(self.connector, '_execute') as exec_mock:
-            exec_mock.side_effect = [('', 'error'), ('', None),
-                                     ('', None), ('', None),
-                                     ('', None)]
-            res = self.connector._connect_to_iscsi_portal(self.CON_PROPS)
-
-        # True refers to "manual scans", since the call to update
-        # node.session.scan didn't fail they are set to manual
-        self.assertEqual((session, True), res)
-        prefix = 'iscsiadm -m node -T tgt1 -p ip1:port1'
-        expected_cmds = [
-            prefix,
-            prefix + ' --interface default --op new',
-            prefix + ' --op update -n node.session.scan -v manual',
-            prefix + ' --login',
-            prefix + ' --op update -n node.startup -v automatic'
-        ]
-        actual_cmds = [' '.join(args[0]) for args in exec_mock.call_args_list]
-        self.assertListEqual(expected_cmds, actual_cmds)
-        self.assertEqual(2, get_sessions_mock.call_count)
-
     @mock.patch.object(iscsi.ISCSIConnector, '_get_iscsi_sessions_full')
     def test_connect_to_iscsi_portal_all_exists_chap(self, get_sessions_mock):
         """Node and session already exists and we use chap authentication."""
